@@ -11,7 +11,10 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-__version__ = '0.14.3'
+__version__ = '0.14.5'
 
-from text_models.place import Mobility, MobilityWeekday, MobilityCluster
-from text_models.vocabulary import Vocabulary, Tokenize, BagOfWords
+try:
+    from text_models.place import Mobility, MobilityWeekday, MobilityCluster
+    from text_models.vocabulary import Vocabulary, Tokenize, BagOfWords
+except ImportError:
+    pass
